@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+   USA.
 
    The author may be contacted at <pfaffben@pilot.msu.edu> on the
    Internet, or as Ben Pfaff, 12167 Airport Rd, DeWitt MI 48820, USA
